@@ -1,5 +1,4 @@
-from __future__ import absolute_import
-from __future__ import print_function
+from __future__ import absolute_import, print_function
 
 import logging as _logging
 import math as _math
@@ -7,7 +6,7 @@ import os as _os
 
 import click
 
-from flytekit.clis.sdk_in_container.constants import CTX_PACKAGES, CTX_PROJECT, CTX_DOMAIN, CTX_VERSION
+from flytekit.clis.sdk_in_container.constants import CTX_DOMAIN, CTX_PACKAGES, CTX_PROJECT, CTX_VERSION
 from flytekit.common import utils as _utils
 from flytekit.common.core import identifier as _identifier
 from flytekit.common.exceptions.scopes import system_entry_point
@@ -36,26 +35,20 @@ def serialize_tasks_only(project, domain, pkgs, version, folder=None):
     for m, k, o in iterate_registerable_entities_in_order(pkgs, include_entities={_sdk_task.SdkTask}):
         name = _utils.fqdn(m.__name__, k, entity_type=o.resource_type)
         _logging.debug("Found module {}\n   K: {} Instantiated in {}".format(m, k, o._instantiated_in))
-        o._id = _identifier.Identifier(
-            o.resource_type,
-            project,
-            domain,
-            name,
-            version
-        )
+        o._id = _identifier.Identifier(o.resource_type, project, domain, name, version)
         loaded_entities.append(o)
 
     zero_padded_length = _determine_text_chars(len(loaded_entities))
     for i, entity in enumerate(loaded_entities):
         serialized = entity.serialize()
         fname_index = str(i).zfill(zero_padded_length)
-        fname = '{}_{}.pb'.format(fname_index, entity._id.name)
-        click.echo('  Writing {} to\n    {}'.format(entity._id, fname))
+        fname = "{}_{}.pb".format(fname_index, entity._id.name)
+        click.echo("  Writing {} to\n    {}".format(entity._id, fname))
         if folder:
             fname = _os.path.join(folder, fname)
         _write_proto_to_file(serialized, fname)
 
-        identifier_fname = '{}_{}.identifier.pb'.format(fname_index, entity._id.name)
+        identifier_fname = "{}_{}.identifier.pb".format(fname_index, entity._id.name)
         if folder:
             identifier_fname = _os.path.join(folder, identifier_fname)
         _write_proto_to_file(entity._id.to_flyte_idl(), identifier_fname)
@@ -92,21 +85,15 @@ def serialize_all(project, domain, pkgs, version, folder=None):
     for m, k, o in iterate_registerable_entities_in_order(pkgs):
         name = _utils.fqdn(m.__name__, k, entity_type=o.resource_type)
         _logging.debug("Found module {}\n   K: {} Instantiated in {}".format(m, k, o._instantiated_in))
-        o._id = _identifier.Identifier(
-            o.resource_type,
-            project,
-            domain,
-            name,
-            version
-        )
+        o._id = _identifier.Identifier(o.resource_type, project, domain, name, version)
         loaded_entities.append(o)
 
     zero_padded_length = _determine_text_chars(len(loaded_entities))
     for i, entity in enumerate(loaded_entities):
         serialized = entity.serialize()
         fname_index = str(i).zfill(zero_padded_length)
-        fname = '{}_{}.pb'.format(fname_index, entity._id.name)
-        click.echo('  Writing {} to\n    {}'.format(entity._id, fname))
+        fname = "{}_{}.pb".format(fname_index, entity._id.name)
+        click.echo("  Writing {} to\n    {}".format(entity._id, fname))
         if folder:
             fname = _os.path.join(folder, fname)
         _write_proto_to_file(serialized, fname)
@@ -116,7 +103,7 @@ def serialize_all(project, domain, pkgs, version, folder=None):
         # project/domain, etc.) made for this serialize call. We should not allow users to specify a different project
         # for instance come registration time, to avoid mismatches between potential internal ids like the TaskTemplate
         # and the registered entity.
-        identifier_fname = '{}_{}.identifier.pb'.format(fname_index, entity._id.name)
+        identifier_fname = "{}_{}.identifier.pb".format(fname_index, entity._id.name)
         if folder:
             identifier_fname = _os.path.join(folder, identifier_fname)
         _write_proto_to_file(entity._id.to_flyte_idl(), identifier_fname)
@@ -133,7 +120,7 @@ def _determine_text_chars(length):
     return _math.ceil(_math.log(length, 10))
 
 
-@click.group('serialize')
+@click.group("serialize")
 @click.pass_context
 def serialize(ctx):
     """
@@ -143,13 +130,17 @@ def serialize(ctx):
         object contains the WorkflowTemplate, along with the relevant tasks for that workflow.  In lieu of Admin,
         this serialization step will set the URN of the tasks to the fully qualified name of the task function.
     """
-    click.echo('Serializing Flyte elements with image {}'.format(_internal_configuration.IMAGE.get()))
+    click.echo("Serializing Flyte elements with image {}".format(_internal_configuration.IMAGE.get()))
 
 
-@click.command('tasks')
-@click.option('-v', '--version', type=str, help='Version to serialize tasks with. This is normally parsed from the'
-                                                'image, but you can override here.')
-@click.option('-f', '--folder', type=click.Path(exists=True))
+@click.command("tasks")
+@click.option(
+    "-v",
+    "--version",
+    type=str,
+    help="Version to serialize tasks with. This is normally parsed from the" "image, but you can override here.",
+)
+@click.option("-f", "--folder", type=click.Path(exists=True))
 @click.pass_context
 def tasks(ctx, version=None, folder=None):
     project = ctx.obj[CTX_PROJECT]
@@ -159,32 +150,40 @@ def tasks(ctx, version=None, folder=None):
     if folder:
         click.echo(f"Writing output to {folder}")
 
-    version = version or ctx.obj[CTX_VERSION] or _internal_configuration.look_up_version_from_image_tag(
-        _internal_configuration.IMAGE.get())
+    version = (
+        version
+        or ctx.obj[CTX_VERSION]
+        or _internal_configuration.look_up_version_from_image_tag(_internal_configuration.IMAGE.get())
+    )
 
     internal_settings = {
-        'project': project,
-        'domain': domain,
-        'version': version,
+        "project": project,
+        "domain": domain,
+        "version": version,
     }
     # Populate internal settings for project/domain/version from the environment so that the file names are resolved
     # with the correct strings. The file itself doesn't need to change though.
     with TemporaryConfiguration(_internal_configuration.CONFIGURATION_PATH.get(), internal_settings):
-        _logging.debug("Serializing with settings\n"
-                       "\n  Project: {}"
-                       "\n  Domain: {}"
-                       "\n  Version: {}"
-                       "\n\nover the following packages {}".format(project, domain, version, pkgs)
-                       )
+        _logging.debug(
+            "Serializing with settings\n"
+            "\n  Project: {}"
+            "\n  Domain: {}"
+            "\n  Version: {}"
+            "\n\nover the following packages {}".format(project, domain, version, pkgs)
+        )
         serialize_tasks_only(project, domain, pkgs, version, folder)
 
 
-@click.command('workflows')
-@click.option('-v', '--version', type=str, help='Version to serialize tasks with. This is normally parsed from the'
-                                                'image, but you can override here.')
+@click.command("workflows")
+@click.option(
+    "-v",
+    "--version",
+    type=str,
+    help="Version to serialize tasks with. This is normally parsed from the" "image, but you can override here.",
+)
 # For now let's just assume that the directory needs to exist. If you're docker run -v'ing, docker will create the
 # directory for you so it shouldn't be a problem.
-@click.option('-f', '--folder', type=click.Path(exists=True))
+@click.option("-f", "--folder", type=click.Path(exists=True))
 @click.pass_context
 def workflows(ctx, version=None, folder=None):
     _logging.getLogger().setLevel(_logging.DEBUG)
@@ -196,23 +195,27 @@ def workflows(ctx, version=None, folder=None):
     domain = ctx.obj[CTX_DOMAIN]
     pkgs = ctx.obj[CTX_PACKAGES]
 
-    version = version or ctx.obj[CTX_VERSION] or _internal_configuration.look_up_version_from_image_tag(
-        _internal_configuration.IMAGE.get())
+    version = (
+        version
+        or ctx.obj[CTX_VERSION]
+        or _internal_configuration.look_up_version_from_image_tag(_internal_configuration.IMAGE.get())
+    )
 
     internal_settings = {
-        'project': project,
-        'domain': domain,
-        'version': version,
+        "project": project,
+        "domain": domain,
+        "version": version,
     }
     # Populate internal settings for project/domain/version from the environment so that the file names are resolved
     # with the correct strings. The file itself doesn't need to change though.
     with TemporaryConfiguration(_internal_configuration.CONFIGURATION_PATH.get(), internal_settings):
-        _logging.debug("Serializing with settings\n"
-                       "\n  Project: {}"
-                       "\n  Domain: {}"
-                       "\n  Version: {}"
-                       "\n\nover the following packages {}".format(project, domain, version, pkgs)
-                       )
+        _logging.debug(
+            "Serializing with settings\n"
+            "\n  Project: {}"
+            "\n  Domain: {}"
+            "\n  Version: {}"
+            "\n\nover the following packages {}".format(project, domain, version, pkgs)
+        )
         serialize_all(project, domain, pkgs, version, folder)
 
 
