@@ -1,46 +1,56 @@
-import os as _os
-import json as _json
-import papermill as _pm
-from google.protobuf import text_format as _text_format, json_format as _json_format
-import importlib as _importlib
 import datetime as _datetime
+import importlib as _importlib
+import inspect as _inspect
+import json as _json
+import os as _os
 import sys as _sys
+
+import papermill as _pm
 import six as _six
+from google.protobuf import json_format as _json_format
+from google.protobuf import text_format as _text_format
+
 from flytekit import __version__
 from flytekit.bin import entrypoint as _entrypoint
-from flytekit.sdk.types import Types as _Types
-from flytekit.common.types import helpers as _type_helpers, primitives as _primitives
-from flytekit.common import constants as _constants, sdk_bases as _sdk_bases, interface as _interface2
-from flytekit.common.exceptions import scopes as _exception_scopes, user as _user_exceptions
-from flytekit.common.tasks import sdk_runnable as _sdk_runnable, spark_task as _spark_task,\
-    output as _task_output, task as _base_tasks
-from flytekit.models import literals as _literal_models, task as _task_models, interface as _interface
-from flytekit.engines import loader as _engine_loader
-import inspect as _inspect
-from flytekit.sdk.spark_types import SparkType as _spark_type
+from flytekit.common import constants as _constants
+from flytekit.common import interface as _interface2
+from flytekit.common.exceptions import scopes as _exception_scopes
+from flytekit.common.exceptions import user as _user_exceptions
+from flytekit.common.tasks import output as _task_output
+from flytekit.common.tasks import sdk_runnable as _sdk_runnable
+from flytekit.common.tasks import spark_task as _spark_task
+from flytekit.common.tasks import task as _base_tasks
+from flytekit.common.types import helpers as _type_helpers
 from flytekit.contrib.notebook.supported_types import notebook_types_map as _notebook_types_map
+from flytekit.engines import loader as _engine_loader
+from flytekit.models import interface as _interface
+from flytekit.models import literals as _literal_models
+from flytekit.models import task as _task_models
+from flytekit.sdk.spark_types import SparkType as _spark_type
+from flytekit.sdk.types import Types as _Types
+
+OUTPUT_NOTEBOOK = "output_notebook"
+
 
-OUTPUT_NOTEBOOK = 'output_notebook'
 def python_notebook(
-        notebook_path='',
-        inputs={},
-        outputs={},
-        cache_version='',
-        retries=0,
-        deprecated='',
-        storage_request=None,
-        cpu_request=None,
-        gpu_request=None,
-        memory_request=None,
-        storage_limit=None,
-        cpu_limit=None,
-        gpu_limit=None,
-        memory_limit=None,
-        cache=False,
-        timeout=None,
-        environment=None,
-        cls=None,
-
+    notebook_path="",
+    inputs={},
+    outputs={},
+    cache_version="",
+    retries=0,
+    deprecated="",
+    storage_request=None,
+    cpu_request=None,
+    gpu_request=None,
+    memory_request=None,
+    storage_limit=None,
+    cpu_limit=None,
+    gpu_limit=None,
+    memory_limit=None,
+    cache=False,
+    timeout=None,
+    environment=None,
+    cls=None,
 ):
     """
     Decorator to create a Python Notebook Task definition.
@@ -48,25 +58,26 @@ def python_notebook(
     :rtype: SdkNotebookTask
     """
     return SdkNotebookTask(
-            notebook_path=notebook_path,
-            inputs=inputs,
-            outputs=outputs,
-            task_type=_constants.SdkTaskType.PYTHON_TASK,
-            discovery_version=cache_version,
-            retries=retries,
-            deprecated=deprecated,
-            storage_request=storage_request,
-            cpu_request=cpu_request,
-            gpu_request=gpu_request,
-            memory_request=memory_request,
-            storage_limit=storage_limit,
-            cpu_limit=cpu_limit,
-            gpu_limit=gpu_limit,
-            memory_limit=memory_limit,
-            discoverable=cache,
-            timeout=timeout or _datetime.timedelta(seconds=0),
-            environment=environment,
-            custom={})
+        notebook_path=notebook_path,
+        inputs=inputs,
+        outputs=outputs,
+        task_type=_constants.SdkTaskType.PYTHON_TASK,
+        discovery_version=cache_version,
+        retries=retries,
+        deprecated=deprecated,
+        storage_request=storage_request,
+        cpu_request=cpu_request,
+        gpu_request=gpu_request,
+        memory_request=memory_request,
+        storage_limit=storage_limit,
+        cpu_limit=cpu_limit,
+        gpu_limit=gpu_limit,
+        memory_limit=memory_limit,
+        discoverable=cache,
+        timeout=timeout or _datetime.timedelta(seconds=0),
+        environment=environment,
+        custom={},
+    )
 
 
 class SdkNotebookTask(_base_tasks.SdkTask):
@@ -77,26 +88,26 @@ class SdkNotebookTask(_base_tasks.SdkTask):
     """
 
     def __init__(
-            self,
-            notebook_path,
-            inputs,
-            outputs,
-            task_type,
-            discovery_version,
-            retries,
-            deprecated,
-            storage_request,
-            cpu_request,
-            gpu_request,
-            memory_request,
-            storage_limit,
-            cpu_limit,
-            gpu_limit,
-            memory_limit,
-            discoverable,
-            timeout,
-            environment,
-            custom
+        self,
+        notebook_path,
+        inputs,
+        outputs,
+        task_type,
+        discovery_version,
+        retries,
+        deprecated,
+        storage_request,
+        cpu_request,
+        gpu_request,
+        memory_request,
+        storage_limit,
+        cpu_limit,
+        gpu_limit,
+        memory_limit,
+        discoverable,
+        timeout,
+        environment,
+        custom,
     ):
 
         if _os.path.isabs(notebook_path) is False:
@@ -112,15 +123,13 @@ class SdkNotebookTask(_base_tasks.SdkTask):
             _task_models.TaskMetadata(
                 discoverable,
                 _task_models.RuntimeMetadata(
-                    _task_models.RuntimeMetadata.RuntimeType.FLYTE_SDK,
-                    __version__,
-                    'notebook'
+                    _task_models.RuntimeMetadata.RuntimeType.FLYTE_SDK, __version__, "notebook",
                 ),
                 timeout,
                 _literal_models.RetryStrategy(retries),
                 False,
                 discovery_version,
-                deprecated
+                deprecated,
             ),
             _interface2.TypedInterface({}, {}),
             custom,
@@ -133,8 +142,8 @@ class SdkNotebookTask(_base_tasks.SdkTask):
                 cpu_limit=cpu_limit,
                 gpu_limit=gpu_limit,
                 memory_limit=memory_limit,
-                environment=environment
-            )
+                environment=environment,
+            ),
         )
         # Add Inputs
         if inputs is not None:
@@ -145,8 +154,9 @@ class SdkNotebookTask(_base_tasks.SdkTask):
             outputs(self)
 
         # Add a Notebook output as a Blob.
-        self.interface.outputs.update(output_notebook=_interface.Variable(_Types.Blob.to_flyte_literal_type(), OUTPUT_NOTEBOOK))
-
+        self.interface.outputs.update(
+            output_notebook=_interface.Variable(_Types.Blob.to_flyte_literal_type(), OUTPUT_NOTEBOOK)
+        )
 
     def _validate_inputs(self, inputs):
         """
@@ -154,7 +164,7 @@ class SdkNotebookTask(_base_tasks.SdkTask):
         :raises: flytekit.common.exceptions.user.FlyteValidationException
         """
         for k, v in _six.iteritems(inputs):
-            sdk_type =_type_helpers.get_sdk_type_from_literal_type(v.type)
+            sdk_type = _type_helpers.get_sdk_type_from_literal_type(v.type)
             if sdk_type not in _notebook_types_map.values():
                 raise _user_exceptions.FlyteValidationException(
                     "Input Type '{}' not supported.  Only Primitives are supported for notebook.".format(sdk_type)
@@ -173,7 +183,8 @@ class SdkNotebookTask(_base_tasks.SdkTask):
 
             if k == OUTPUT_NOTEBOOK:
                 raise ValueError(
-                    "{} is a reserved output keyword. Please use a different output name.".format(OUTPUT_NOTEBOOK))
+                    "{} is a reserved output keyword. Please use a different output name.".format(OUTPUT_NOTEBOOK)
+                )
 
             sdk_type = _type_helpers.get_sdk_type_from_literal_type(v.type)
             if sdk_type not in _notebook_types_map.values():
@@ -212,11 +223,18 @@ class SdkNotebookTask(_base_tasks.SdkTask):
         :returns: Depends on the behavior of the specific task in the unit engine.
         """
 
-        return _engine_loader.get_engine('unit').get_task(self).execute(
-            _type_helpers.pack_python_std_map_to_literal_map(input_map, {
-                k: _type_helpers.get_sdk_type_from_literal_type(v.type)
-                for k, v in _six.iteritems(self.interface.inputs)
-            })
+        return (
+            _engine_loader.get_engine("unit")
+            .get_task(self)
+            .execute(
+                _type_helpers.pack_python_std_map_to_literal_map(
+                    input_map,
+                    {
+                        k: _type_helpers.get_sdk_type_from_literal_type(v.type)
+                        for k, v in _six.iteritems(self.interface.inputs)
+                    },
+                )
+            )
         )
 
     @_exception_scopes.system_entry_point
@@ -227,11 +245,18 @@ class SdkNotebookTask(_base_tasks.SdkTask):
         :rtype: dict[Text, T]
         :returns: The output produced by this task in Python standard format.
         """
-        return _engine_loader.get_engine('local').get_task(self).execute(
-            _type_helpers.pack_python_std_map_to_literal_map(input_map, {
-                k: _type_helpers.get_sdk_type_from_literal_type(v.type)
-                for k, v in _six.iteritems(self.interface.inputs)
-            })
+        return (
+            _engine_loader.get_engine("local")
+            .get_task(self)
+            .execute(
+                _type_helpers.pack_python_std_map_to_literal_map(
+                    input_map,
+                    {
+                        k: _type_helpers.get_sdk_type_from_literal_type(v.type)
+                        for k, v in _six.iteritems(self.interface.inputs)
+                    },
+                )
+            )
         )
 
     @_exception_scopes.system_entry_point
@@ -246,27 +271,24 @@ class SdkNotebookTask(_base_tasks.SdkTask):
             working directory (with the names provided), which will in turn allow Flyte Propeller to push along the
             workflow.  Where as local engine will merely feed the outputs directly into the next node.
         """
-        inputs_dict = _type_helpers.unpack_literal_map_to_sdk_python_std(inputs, {
-            k: _type_helpers.get_sdk_type_from_literal_type(v.type) for k, v in _six.iteritems(self.interface.inputs)
-        })
+        inputs_dict = _type_helpers.unpack_literal_map_to_sdk_python_std(
+            inputs,
+            {k: _type_helpers.get_sdk_type_from_literal_type(v.type) for k, v in _six.iteritems(self.interface.inputs)},
+        )
 
         input_notebook_path = self._notebook_path
         # Execute Notebook via Papermill.
-        output_notebook_path = input_notebook_path.split(".ipynb")[0] + '-out.ipynb'
-        _pm.execute_notebook(
-            input_notebook_path,
-            output_notebook_path,
-            parameters=inputs_dict
-        )
+        output_notebook_path = input_notebook_path.split(".ipynb")[0] + "-out.ipynb"
+        _pm.execute_notebook(input_notebook_path, output_notebook_path, parameters=inputs_dict)
 
         # Parse Outputs from Notebook.
         outputs = None
         with open(output_notebook_path) as json_file:
             data = _json.load(json_file)
-            for p in data['cells']:
-                meta = p['metadata']
+            for p in data["cells"]:
+                meta = p["metadata"]
                 if "outputs" in meta["tags"]:
-                    outputs = ' '.join(p['outputs'][0]['data']['text/plain'])
+                    outputs = " ".join(p["outputs"][0]["data"]["text/plain"])
 
         if outputs is not None:
             dict = _literal_models._literals_pb2.LiteralMap()
@@ -274,15 +296,14 @@ class SdkNotebookTask(_base_tasks.SdkTask):
 
         # Add output_notebook as an output to the task.
         output_notebook = _task_output.OutputReference(
-            _type_helpers.get_sdk_type_from_literal_type(_Types.Blob.to_flyte_literal_type()))
+            _type_helpers.get_sdk_type_from_literal_type(_Types.Blob.to_flyte_literal_type())
+        )
         output_notebook.set(output_notebook_path)
 
         output_literal_map = _literal_models.LiteralMap.from_flyte_idl(dict)
         output_literal_map.literals[OUTPUT_NOTEBOOK] = output_notebook.sdk_value
 
-        return {
-            _constants.OUTPUT_FILE_NAME: output_literal_map
-        }
+        return {_constants.OUTPUT_FILE_NAME: output_literal_map}
 
     @property
     def container(self):
@@ -307,21 +328,24 @@ class SdkNotebookTask(_base_tasks.SdkTask):
             "--inputs",
             "{{.input}}",
             "--output-prefix",
-            "{{.outputPrefix}}"]
+            "{{.outputPrefix}}",
+            "--raw-output-data-prefix",
+            "{{.rawOutputDataPrefix}}",
+        ]
         return self._container
 
     def _get_container_definition(
-            self,
-            storage_request=None,
-            cpu_request=None,
-            gpu_request=None,
-            memory_request=None,
-            storage_limit=None,
-            cpu_limit=None,
-            gpu_limit=None,
-            memory_limit=None,
-            environment=None,
-            **kwargs
+        self,
+        storage_request=None,
+        cpu_request=None,
+        gpu_request=None,
+        memory_request=None,
+        storage_limit=None,
+        cpu_limit=None,
+        gpu_limit=None,
+        memory_limit=None,
+        environment=None,
+        **kwargs
     ):
         """
         :param Text storage_request:
@@ -344,61 +368,29 @@ class SdkNotebookTask(_base_tasks.SdkTask):
         requests = []
         if storage_request:
             requests.append(
-                _task_models.Resources.ResourceEntry(
-                    _task_models.Resources.ResourceName.STORAGE,
-                    storage_request
-                )
+                _task_models.Resources.ResourceEntry(_task_models.Resources.ResourceName.STORAGE, storage_request)
             )
         if cpu_request:
-            requests.append(
-                _task_models.Resources.ResourceEntry(
-                    _task_models.Resources.ResourceName.CPU,
-                    cpu_request
-                )
-            )
+            requests.append(_task_models.Resources.ResourceEntry(_task_models.Resources.ResourceName.CPU, cpu_request))
         if gpu_request:
-            requests.append(
-                _task_models.Resources.ResourceEntry(
-                    _task_models.Resources.ResourceName.GPU,
-                    gpu_request
-                )
-            )
+            requests.append(_task_models.Resources.ResourceEntry(_task_models.Resources.ResourceName.GPU, gpu_request))
         if memory_request:
             requests.append(
-                _task_models.Resources.ResourceEntry(
-                    _task_models.Resources.ResourceName.MEMORY,
-                    memory_request
-                )
+                _task_models.Resources.ResourceEntry(_task_models.Resources.ResourceName.MEMORY, memory_request)
             )
 
         limits = []
         if storage_limit:
             limits.append(
-                _task_models.Resources.ResourceEntry(
-                    _task_models.Resources.ResourceName.STORAGE,
-                    storage_limit
-                )
+                _task_models.Resources.ResourceEntry(_task_models.Resources.ResourceName.STORAGE, storage_limit)
             )
         if cpu_limit:
-            limits.append(
-                _task_models.Resources.ResourceEntry(
-                    _task_models.Resources.ResourceName.CPU,
-                    cpu_limit
-                )
-            )
+            limits.append(_task_models.Resources.ResourceEntry(_task_models.Resources.ResourceName.CPU, cpu_limit))
         if gpu_limit:
-            limits.append(
-                _task_models.Resources.ResourceEntry(
-                    _task_models.Resources.ResourceName.GPU,
-                    gpu_limit
-                )
-            )
+            limits.append(_task_models.Resources.ResourceEntry(_task_models.Resources.ResourceName.GPU, gpu_limit))
         if memory_limit:
             limits.append(
-                _task_models.Resources.ResourceEntry(
-                    _task_models.Resources.ResourceName.MEMORY,
-                    memory_limit
-                )
+                _task_models.Resources.ResourceEntry(_task_models.Resources.ResourceName.MEMORY, memory_limit)
             )
 
         return _sdk_runnable.SdkRunnableContainer(
@@ -406,45 +398,45 @@ class SdkNotebookTask(_base_tasks.SdkTask):
             args=[],
             resources=_task_models.Resources(limits=limits, requests=requests),
             env=environment,
-            config={}
+            config={},
         )
 
 
 def spark_notebook(
-        notebook_path,
-        inputs={},
-        outputs={},
-        spark_conf=None,
-        cache_version='',
-        retries=0,
-        deprecated='',
-        cache=False,
-        timeout=None,
-        environment=None,
+    notebook_path,
+    inputs={},
+    outputs={},
+    spark_conf=None,
+    cache_version="",
+    retries=0,
+    deprecated="",
+    cache=False,
+    timeout=None,
+    environment=None,
 ):
     """
     Decorator to create a Notebook spark task. This task will connect to a Spark cluster, configure the environment,
     and then execute the code within the notebook_path as the Spark driver program.
     """
     return SdkNotebookSparkTask(
-            notebook_path=notebook_path,
-            inputs=inputs,
-            outputs=outputs,
-            spark_conf=spark_conf,
-            discovery_version=cache_version,
-            retries=retries,
-            deprecated=deprecated,
-            discoverable=cache,
-            timeout=timeout or _datetime.timedelta(seconds=0),
-            environment=environment or {},
-        )
+        notebook_path=notebook_path,
+        inputs=inputs,
+        outputs=outputs,
+        spark_conf=spark_conf,
+        discovery_version=cache_version,
+        retries=retries,
+        deprecated=deprecated,
+        discoverable=cache,
+        timeout=timeout or _datetime.timedelta(seconds=0),
+        environment=environment or {},
+    )
 
 
 def _find_instance_module():
     frame = _inspect.currentframe()
     while frame:
-        if frame.f_code.co_name == '<module>':
-            return frame.f_globals['__name__']
+        if frame.f_code.co_name == "<module>":
+            return frame.f_globals["__name__"]
         frame = frame.f_back
     return None
 
@@ -457,40 +449,40 @@ class SdkNotebookSparkTask(SdkNotebookTask):
     """
 
     def __init__(
-            self,
-            notebook_path,
-            inputs,
-            outputs,
-            spark_conf,
-            discovery_version,
-            retries,
-            deprecated,
-            discoverable,
-            timeout,
-            environment=None,
+        self,
+        notebook_path,
+        inputs,
+        outputs,
+        spark_conf,
+        discovery_version,
+        retries,
+        deprecated,
+        discoverable,
+        timeout,
+        environment=None,
     ):
 
         spark_exec_path = _os.path.abspath(_entrypoint.__file__)
-        if spark_exec_path.endswith('.pyc'):
+        if spark_exec_path.endswith(".pyc"):
             spark_exec_path = spark_exec_path[:-1]
 
         if spark_conf is None:
             # Parse spark_conf from notebook if not set at task_level.
             with open(notebook_path) as json_file:
                 data = _json.load(json_file)
-                for p in data['cells']:
-                    meta = p['metadata']
+                for p in data["cells"]:
+                    meta = p["metadata"]
                     if "tags" in meta:
                         if "conf" in meta["tags"]:
-                            sc_str = ' '.join(p["source"])
+                            sc_str = " ".join(p["source"])
                             ldict = {}
-                            exec (sc_str, globals(), ldict)
-                            spark_conf = ldict['spark_conf']
+                            exec(sc_str, globals(), ldict)
+                            spark_conf = ldict["spark_conf"]
 
             spark_job = _task_models.SparkJob(
                 spark_conf=spark_conf,
-                main_class= "",
-                spark_type= _spark_type.PYTHON,
+                main_class="",
+                spark_type=_spark_type.PYTHON,
                 hadoop_conf={},
                 application_file="local://" + spark_exec_path,
                 executor_path=_sys.executable,
@@ -518,11 +510,7 @@ class SdkNotebookSparkTask(SdkNotebookTask):
             _json_format.MessageToDict(spark_job),
         )
 
-    def _get_container_definition(
-            self,
-            environment=None,
-            **kwargs
-    ):
+    def _get_container_definition(self, environment=None, **kwargs):
         """
         :rtype: flytekit.models.task.Container
         """
@@ -532,5 +520,5 @@ class SdkNotebookSparkTask(SdkNotebookTask):
             args=[],
             resources=_task_models.Resources(limits=[], requests=[]),
             env=environment or {},
-            config={}
-        )
\ No newline at end of file
+            config={},
+        )
