@@ -4,12 +4,11 @@ import os as _os
 import sys as _sys
 import uuid as _uuid
 
+from flytekit.common.exceptions.user import FlyteUserException as _FlyteUserException
 from flytekit.configuration import gcp as _gcp_config
 from flytekit.interfaces import random as _flyte_random
 from flytekit.interfaces.data import common as _common_data
 from flytekit.tools import subprocess as _subprocess
-from flytekit.common.exceptions.user import FlyteUserException as _FlyteUserException
-
 
 if _sys.version_info >= (3,):
     from shutil import which as _which
@@ -29,6 +28,19 @@ def _amend_path(path):
 class GCSProxy(_common_data.DataProxy):
     _GS_UTIL_CLI = "gsutil"
 
+    def __init__(self, raw_output_data_prefix_override: str = None):
+        """
+        :param raw_output_data_prefix_override: Instead of relying on the AWS or GCS configuration (see
+            S3_SHARD_FORMATTER for AWS and GCS_PREFIX for GCP) setting when computing the shard
+            path (_get_shard_path), use this prefix instead as a base. This code assumes that the
+            path passed in is correct. That is, an S3 path won't be passed in when running on GCP.
+        """
+        self._raw_output_data_prefix_override = raw_output_data_prefix_override
+
+    @property
+    def raw_output_data_prefix_override(self) -> str:
+        return self._raw_output_data_prefix_override
+
     @staticmethod
     def _check_binary():
         """
@@ -116,19 +128,18 @@ class GCSProxy(_common_data.DataProxy):
         GCSProxy._check_binary()
 
         cmd = self._maybe_with_gsutil_parallelism(
-           "cp",
-           "-r",
-           _amend_path(local_path),
-           remote_path if remote_path.endswith("/") else remote_path + "/"
+            "cp", "-r", _amend_path(local_path), remote_path if remote_path.endswith("/") else remote_path + "/",
         )
         return _update_cmd_config_and_execute(cmd)
 
-    def get_random_path(self):
+    def get_random_path(self) -> str:
         """
-        :rtype: Text
+        If this object was created with a raw output data prefix, usually set by Propeller/Plugins at execution time
+        and piped all the way here, it will be used instead of referencing the GCS_PREFIX configuration.
         """
         key = _uuid.UUID(int=_flyte_random.random.getrandbits(128)).hex
-        return _os.path.join(_gcp_config.GCS_PREFIX.get(), key)
+        prefix = self.raw_output_data_prefix_override or _gcp_config.GCS_PREFIX.get()
+        return _os.path.join(prefix, key)
 
     def get_random_directory(self):
         """
