@@ -2,7 +2,8 @@ from __future__ import absolute_import
 
 import six as _six
 
-from flytekit.common import workflow as _common_workflow, promise as _promise
+from flytekit.common import promise as _promise
+from flytekit.common import workflow as _common_workflow
 from flytekit.common.types import helpers as _type_helpers
 
 
@@ -20,7 +21,7 @@ class Input(_promise.Input):
         :param bool required: If set, default must be None
         :param T default: If this is not a required input, the value will default to this value.  Specify as a kwarg.
         """
-        super(Input, self).__init__('', _type_helpers.python_std_to_sdk_type(sdk_type), help=help, **kwargs)
+        super(Input, self).__init__("", _type_helpers.python_std_to_sdk_type(sdk_type), help=help, **kwargs)
 
 
 class Output(_common_workflow.Output):
@@ -37,10 +38,7 @@ class Output(_common_workflow.Output):
             this value be provided as the SDK might not always be able to infer the correct type.
         """
         super(Output, self).__init__(
-            '',
-            value,
-            sdk_type=_type_helpers.python_std_to_sdk_type(sdk_type) if sdk_type else None,
-            help=help
+            "", value, sdk_type=_type_helpers.python_std_to_sdk_type(sdk_type) if sdk_type else None, help=help,
         )
 
 
@@ -117,5 +115,6 @@ def workflow(nodes, inputs=None, outputs=None, cls=None, on_failure=None):
         inputs=[v.rename_and_return_reference(k) for k, v in sorted(_six.iteritems(inputs or {}))],
         outputs=[v.rename_and_return_reference(k) for k, v in sorted(_six.iteritems(outputs or {}))],
         nodes=[v.assign_id_and_return(k) for k, v in sorted(_six.iteritems(nodes))],
-        metadata=_common_workflow._workflow_models.WorkflowMetadata(on_failure=on_failure))
+        metadata=_common_workflow._workflow_models.WorkflowMetadata(on_failure=on_failure),
+    )
     return wf
